import { dirname, resolve } from 'path';
import { existsSync, copyFileSync } from 'fs';
import { fileURLToPath } from 'url';
import tailwindcssPlugin from 'tailwindcss';
import autoprefixerPlugin from 'autoprefixer';
const __filename = fileURLToPath(import.meta.url);
const __dirname = dirname(__filename);
export const TAILWIND_CONFIG_FILE = 'tailwind.config.js';
/**
 * Zuby.js plugin that integrates Tailwind CSS
 * with your application.
 * @param options
 * @returns ZubyPlugin
 */
export default ({ configFile, nesting = false } = {}) => ({
    name: 'zuby-tailwind-plugin',
    description: 'Adds Tailwind CSS to your Zuby.js application',
    hooks: {
        'zuby:config:setup': async ({ config, injectToEntry }) => {
            const { srcDir = './' } = config;
            configFile = configFile || findTailwindConfig(srcDir) || createTailwindConfig(srcDir);
            config.vite = config.vite || {};
            config.vite.css = config.vite?.css || {};
            config.vite.css.postcss = config.vite.css.postcss || {};
            if (typeof config.vite.css.postcss === 'string') {
                console.error(`[zuby-tailwind-plugin] Invalid configuration for 'vite.css.postcss'. Expected an object, but got a string.`);
                return;
            }
            config.vite.css.postcss.plugins = config.vite.css.postcss.plugins || [];
            config.vite.css.postcss.plugins.push(tailwindcssPlugin(configFile), autoprefixerPlugin());
            if (nesting) {
                const tailwindcssNestingPlugin = (await import('tailwindcss/nesting/index.js')).default;
                config.vite.css.postcss.plugins.push(tailwindcssNestingPlugin());
            }
        },
    },
});
export function createTailwindConfig(srcDir) {
    const isTs = existsSync(resolve(srcDir, 'tsconfig.json'));
    const configFile = isTs
        ? TAILWIND_CONFIG_FILE.replace('.js', '.ts')
        : TAILWIND_CONFIG_FILE.replace('.js', '.mjs');
    copyFileSync(resolve(__dirname, 'examples', isTs ? 'ts' : 'js', configFile), resolve(srcDir, configFile));
    return configFile;
}
export function findTailwindConfig(srcDir) {
    return [
        resolve(srcDir, TAILWIND_CONFIG_FILE),
        resolve(srcDir, TAILWIND_CONFIG_FILE.replace('.js', '.mjs')),
        resolve(srcDir, TAILWIND_CONFIG_FILE.replace('.js', '.cjs')),
        resolve(srcDir, TAILWIND_CONFIG_FILE.replace('.js', '.ts')),
    ].find(file => existsSync(file));
}
